#################################################################################
# Created       : Martin Foster
# Modified      : 11/14/2000
#################################################################################
#
# Param - Modules part of Webchat designed to handle parameters diffrently
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################
package Webchat::Param;

use strict;							# Strict variable enforcement

use Webchat::Login;						# Login procedures
use Webchat::Crypto;						# Cryptographic Module


#################################################################################
# Data Members
#################################################################################

#################################################################################
# Sub-Routines
#################################################################################

#####################
# GetParam
#
# Due to the annoyance of having to retrieve parameters from the $cgi->param
# command, I have opted to move them directly into a hash.  Passable to functions
# with little or no trouble and generally avoiding having the same value 
# re-applied to the parameter, causing problems for changes and easier calling
# via a hash.

sub GetParam
{
	#####################
	# Data members	
	my $cgi  = shift;					# Handle to CGI
	my $hash = shift;					# Reference to hash

	my @names;						# Array of named parameters reveived
	my $param;						# Specific parameter


	#####################
	# Program area


	# Decrypt and add to hash
	if (defined($cgi->param('SEC')))
	{
		my $string = $cgi->param('SEC');
		$cgi->delete('SEC');

		Webchat::Crypto::decryptParam($cgi, $string, $hash);
	}

	# Get list of all parameters received
	@names = $cgi->param();	
	
	# Cycle though parameter list
	while ($param = shift(@names))
	{
		$hash->{$param} = $cgi->param($param);		# Create hash with parameters
		$cgi->delete($param);				# Delete parameter list as one goes
	}
}


#####################
# Embed Information
#
# This function will embed retreived parameters for the next pass.    By making use of
# the Cypto module the use of text mangling and unmangling is no longer needed.

sub Embed                                                       # Database handle, CGI, Parameters
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $Statement;						# SQL Statement

	my $cgi = shift;					# CGI Handle
	my $choice = shift;					# Choice of the matter

	my $string;						# Encrypted parameter string


	#####################
	# Data members
	$string = Webchat::Crypto::encryptParam($cgi, @_);	# Retreive encrypted string

	# If embed
	if ($choice == 0)
	{ print "\t", $cgi->hidden('SEC', $string), "\n"; }

	# Inline embeding
	elsif ($choice == 1)
	{ return "\?SEC\=$string"; }
}

# Alias for Normal
sub EmbedNormal
{ Embed(shift, shift, 0, @_); }

# Alias for Inline
sub EmbedInline
{ return Embed(shift, shift, 1, @_); }

1;								# Return true
