#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 01/20/2000
#################################################################################
#
# Guest - Script part of Webchat designed to lead guests to rooms
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs

use FileHandle;							# Used to flush buffers
use strict;							# Strict variable enforcement

use Webchat::Database;						# Database handler
use Webchat::Param;						# Parameter control
use Webchat::Post;						# Post handler
use Webchat::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $Database;							# Database handle
my $cgi;							# Common gateway interface handle

my %param;							# Parameter hash


#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# Create CGI Handle

	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL
	Webchat::Param::GetParam($cgi, \%param);		# Retreive parameters

	# File header
	print $cgi->header();

	# Flush standard output
	autoflush STDOUT 1;
	print "";


	# If undefined list realms, puppets and links
	if (defined($param{'READONLY'}))
	{ RealmDisplay($Database, $cgi, \%param); }

	# Otherwise entrance
	elsif (defined($param{'ENTRANCE'}))
	{ Entrance($Database, $cgi, \%param); }

	else
	{ RealmSelect($Database, $cgi, \%param); }

	$Database->disconnect();				# Disconnect database handle

#################################################################################
# Sub-Routines
#################################################################################

#####################
# Entrance
#
# The entrace simply lists all people in a room, and the rooms information.  This
# is no different then normal applications

sub Entrance							# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list

	my $info;						# Room information

	#####################
	# Program area

	# Cleanup
	delete $param->{'ENTRANCE'};

	# Display HTML
	# Display header
	Webchat::Database::DocumentGetHeader($Database);

	# Call and display entrance
	Webchat::Who::WhoGuest($Database, $cgi, $param);

	# Retreive realm information
	($info) = Webchat::Database::DataGetRealmDescription($Database, $param->{'ROOM'});

	# Display realm information
	if (defined($info))
	{ print "$info\n"; }

	# HTML footer
	Webchat::Database::DocumentGetFooter($Database);
}

#####################
# Realm Display
#
# Will create a single pane window for use, expressly to be able to view what is
# happening inside the realm.  This differs considerably from normal use. 

sub RealmDisplay						# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list


	#####################
	# Program area


	# Assign a user
	$param->{'USER'} = 'Guest';
	$param->{'CHAR'} = 'Guest';

	# Display HTML
	# Display header
	Webchat::Database::DocumentGetHeaderPlain($Database);

	# Simply show streaming
	Webchat::Post::HandleStream($Database, $cgi, $param);

	# HTML footer
	print $cgi->end_html();
}

#####################
# Realm Selections
#
# Allows the guest to select a public realm that allows gues access.  This is
# as to allow harser rooms to may be public but do not want the peering eyes
# of guests to see.

sub RealmSelect							# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $Statement;						# SQL Statement

	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list

	my $inline;						# Inline parameter handling

	my $realms;						# Formatted list of realms
	my @realms;						# List of realms

	my %portal;						# Portal hash


	#####################
	# Program area

	# Link DBM to hash
	Webchat::Database::GetHashPortal($Database, \%portal);
	
	# Retreive and format values for Realms
	Webchat::Database::GetListGuestRealms($Database, \@realms);	
	$realms  = $cgi->scrolling_list('ROOM', \@realms, $realms[0], 5);


	# Display HTML and Title
	Webchat::Database::DocumentGetHeader($Database);
	print "$portal{'TagTitle'}\n<BR>\n";

	# Create inline link
	$inline = Webchat::Param::EmbedInline($Database, $cgi, %{$param});

	# Realm Section
	print $cgi->start_form();
	Webchat::Table::MakeTop($cgi);
	Webchat::Table::MakeSingle($cgi, $portal{'TagSecRealm'});
	Webchat::Table::MakeSingle($cgi, "<A HREF=\"$portal{LnkGlobalWho}$inline\" TARGET=\"_TOP\">$portal{TagLnkGlobalWho}</A>");
	Webchat::Table::MakeBlank($cgi);

	Webchat::Table::MakeValid($cgi, $portal{'TagSelectRealm'},   $realms);
	Webchat::Table::MakeBlank($cgi);
	
	Webchat::Table::MakeValid($cgi, $cgi->submit($portal{'TxtSubmitRealms'}), $cgi->reset($portal{'TxtResetRealms'}));
	Webchat::Table::MakeBottom($cgi);

	# Embed for next pass
	Webchat::Param::EmbedNormal($Database, $cgi, %{$param}, 'ENTRANCE', 'true');
	print $cgi->end_form(), "\n";

	# HTML footer
	Webchat::Database::DocumentGetFooter($Database);
}
