#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 01/10/2000
#################################################################################
#
# Portal - Script part of Webchat designed to authenthicate and and lead to realms
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
#use strict;							# Strict variable enforcement

use Webchat::Database;						# Database handler
use Webchat::Login;						# Login functionality
use Webchat::Param;						# Parameter control
use Webchat::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $Database;							# Database handle
my $cgi;							# Common gateway interface handle

my %param;							# Parameter hash


#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# Create CGI Handle

	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL
	Webchat::Param::GetParam($cgi, \%param);		# Retreive parameters

	print $cgi->header();					# File header
	Webchat::Database::DocumentGetHeader($Database);	# HTML header

	if ( Webchat::Login::GetVerificationNormal($Database, $cgi, \%param) )
	{
		# If undefined list realms, puppets and links
		unless (defined($param{'THIRDCHAPTER'}))
		{ SecondChapter($Database, $cgi, \%param); }

		# Otherwise open gateway
		elsif (defined($param{'THIRDCHAPTER'}))
		{ ThirdChapter($Database, $cgi, \%param); }
	}

	Webchat::Database::DocumentGetFooter($Database);	# HTML footer
	$Database->disconnect();				# Disconnect database handle

#################################################################################
# Sub-Routines
#################################################################################

#####################
# Second Chapter
#
# Unusual name given to a part of the script that will be exected once the user
# has been authenthicated.   

sub SecondChapter						# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $Statement;						# SQL Statement

	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list

	my $inline;						# Inline embeding of data
	my $javascript;						# Javascript control
	my $realms;						# Formatted list of realms
	my $puppets;						# Formatted list of puppets

	my @realms;						# List of realms
	my @puppets;						# List of puppets

	my %portal;						# Portal hash


	#####################
	# Program area

	# Link DBM to hash
	Webchat::Database::GetHashPortal($Database, \%portal);
	
	# Javascript Options
	# Retreive Javascript choice
	($javascript) = Webchat::Database::DataGetJavascript($Database, $param->{'USER'});
	
	# Possibly display Javascript
	if ($javascript eq 'yes')
	{ Webchat::Database::DocumentGetJavascript($Database); }


	# Retreive and format values for Realms and Puppets
	Webchat::Database::GetListPublicRealms($Database, \@realms);	
	Webchat::Database::GetListPuppetYours($Database,  \@puppets, $param->{'USER'});	

	$realms  = $cgi->scrolling_list('ROOM', \@realms, $realms[0], 5);
	$puppets = $cgi->scrolling_list('CHAR', \@puppets, $puppets[0], 5);


	# Display title
	print "$portal{'TagTitle'}\n<BR>\n";

	# Create inline link
	$inline = Webchat::Param::EmbedInline($Database, $cgi, %{$param});

	# Realm Section
	print $cgi->start_form();
	Webchat::Table::MakeTop($cgi);
	Webchat::Table::MakeSingle($cgi, $portal{'TagSecRealm'});
	Webchat::Table::MakeSingle($cgi, "<A HREF=\"$portal{LnkGlobalWho}$inline\" TARGET=\"_TOP\">$portal{TagLnkGlobalWho}</A>");
	Webchat::Table::MakeBlank($cgi);

	Webchat::Table::MakeValid($cgi, $portal{'TagSelectPuppet'},  $puppets);
	Webchat::Table::MakeBlank($cgi);
	Webchat::Table::MakeValid($cgi, $portal{'TagSelectRealm'},   $realms);
	Webchat::Table::MakeBlank($cgi);
	Webchat::Table::MakeValid($cgi, $portal{'TagSelectPrivate'}, $cgi->textfield('ALTROOM', '', 20, 30));
	Webchat::Table::MakeBlank($cgi);
	
	Webchat::Table::MakeValid($cgi, $cgi->submit($portal{'TxtSubmitRealms'}), $cgi->reset($portal{'TxtResetRealms'}));
	Webchat::Table::MakeBottom($cgi);

	# Embed for next pass
	Webchat::Param::EmbedNormal($Database, $cgi, %{$param}, 'THIRDCHAPTER', 'true');
	print $cgi->end_form(), "\n";


	print "<BR>\n<BR>\n";					# Spacer
		
	# Determine supervisory rights
	# Prepare and execute
	$Statement = $Database->prepare("SELECT PuppeteerSuperPrivs FROM Puppeteer WHERE PuppeteerLogin=?");
	$Statement->execute($param->{'USER'});

	# Capture and finish
	my $choice = $Statement->fetchrow();
	$Statement->finish();

	Webchat::Table::MakeTop($cgi);
	Webchat::Table::MakeSingle($cgi, $portal{'TagSecPuppeteer'});
	Webchat::Table::MakeBlank($cgi);


	# Link handling
	if ($javascript eq 'no')
	{
		# Non javascript links
		Webchat::Table::MakeSingle($cgi, "<A HREF=\"$portal{'LnkPuppeteer'}$inline\" TARGET=\"_TOP\">$portal{'TagLnkPuppeteer'}</A>");
		Webchat::Table::MakeSingle($cgi, "<A HREF=\"$portal{'LnkPuppet'}$inline\" TARGET=\"_TOP\">$portal{'TagLnkPuppet'}</A>");
		Webchat::Table::MakeSingle($cgi, "<A HREF=\"$portal{'LnkIgnore'}$inline\" TARGET=\"_TOP\">$portal{'TagLnkIgnore'}</A>");

		# Display following button if supervisor
		if ($choice eq 'yes')
		{ Webchat::Table::MakeSingle($cgi, "<A HREF=\"$portal{'LnkRealm'}$inline\" TARGET=\"_TOP\">$portal{'TagLnkSupervisor'}</A>"); }
	}
	else
	{
		# Javascript links
		Webchat::Table::MakeSingle($cgi, "<A HREF=\"javascript:popup_window('$portal{'LnkPuppeteer'}$inline',1)\">$portal{'TagLnkPuppeteer'}</A>");
		Webchat::Table::MakeSingle($cgi, "<A HREF=\"javascript:popup_window('$portal{'LnkPuppet'}$inline',1)\">$portal{'TagLnkPuppet'}</A>");
		Webchat::Table::MakeSingle($cgi, "<A HREF=\"javascript:popup_window('$portal{'LnkIgnore'}$inline',1)\">$portal{'TagLnkIgnore'}</A>");

		# Display following button if supervisor
		if ($choice eq 'yes')
		{ Webchat::Table::MakeSingle($cgi, "<A HREF=\"javascript:popup_window('$portal{'LnkRealm'}$inline',1)\">$portal{'TagLnkSupervisor'}</A>"); }
	}
	Webchat::Table::MakeBottom($cgi);
}


#####################
# Third Chapter
#
# Unusual name given to a part of the script that will be exected once the user  
# in his infinit wisdom has selected a puppet and realm

sub ThirdChapter						# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list

	my $choice;						# To be or not to be
	my $room;						# Room name
	my $info;						# Room information

	#####################
	# Program area

	# Cleanup
	delete $param->{'THIRDCHAPTER'};

	# Determine need to create a room
	if (defined($param->{'ALTROOM'}) && (length(($param->{'ALTROOM'})) > 2))
	{
		# Data Assignment
		$room = $param->{'ALTROOM'};
		$room =~ s/'/`/;

		# Retreive query information
		($choice) = Webchat::Database::DataGetRealmExistence($Database, $room);

		# Create if not found
		unless (defined($choice))
		{
			$Database->do("INSERT INTO Realm 
				(RealmName,
				 RealmLanguage,
				 RealmAccess,
				 RealmGuests,
				 RealmPublic,
				 RealmTags,
				 RealmImageHeight,
				 RealmImageWidth,
				 RealmTimestamp)
				VALUES(?, 'relaxed', 'relaxed', 'yes', 'no', 'relaxed', '0', '0', ?)", {}, 
			 $room, 
			 time); 			
		}
		
		# Assign one to the other (as to be called properly)
		$param->{'ROOM'} = $room;
	}

	# Call and display entrance
	Webchat::Who::WhoEntrance($Database, $cgi, $param);

	# Retreive realm information
	($info) = Webchat::Database::DataGetRealmDescription($Database, $param->{'ROOM'});

	# Display realm information
	if (defined($info))
	{ print "$info\n"; }
}
